Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3385)

Unified Diff: extensions/browser/extension_web_contents_observer.cc

Issue 2716583003: Rename Origin.unique() to opaque().
Patch Set: Update new uses post-rebase Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/shell/browser/shell_content_browser_client.cc ('k') | media/audio/audio_output_device.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: extensions/browser/extension_web_contents_observer.cc
diff --git a/extensions/browser/extension_web_contents_observer.cc b/extensions/browser/extension_web_contents_observer.cc
index 0364f078e897aaf6e19a64c1fbb7e7b6f1225a7f..3fd73182f4fd5dc57b0d9fea5b67d53bc80e6145 100644
--- a/extensions/browser/extension_web_contents_observer.cc
+++ b/extensions/browser/extension_web_contents_observer.cc
@@ -226,10 +226,9 @@ const Extension* ExtensionWebContentsObserver::GetExtensionFromFrame(
const url::Origin& origin(render_frame_host->GetLastCommittedOrigin());
// Without site isolation, this check is needed to eliminate non-extension
// schemes. With site isolation, this is still needed to exclude sandboxed
- // extension frames with a unique origin.
- if (origin.unique() ||
- site_url != content::SiteInstance::GetSiteForURL(browser_context,
- origin.GetURL()))
+ // extension frames with an opaque origin.
+ if (origin.opaque() || site_url != content::SiteInstance::GetSiteForURL(
+ browser_context, origin.GetURL()))
return nullptr;
}
« no previous file with comments | « content/shell/browser/shell_content_browser_client.cc ('k') | media/audio/audio_output_device.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698